=============
Flask-ERPPeek
=============

Introduction
============

Flask-ERPPeek is an extension for the `Flask <http://flask.pocoo.org>`_
micro-framework and `OpenERP <http://www.openerp.com>`_ based
on `Flask-OpenERP <https://github.com/matrixise/flask-openerp>`_
